@@ -964,243 +964,4 @@ adjust <- function(source, target, remove = TRUE, add = TRUE, value = NA,
   } else {
     return(sources[[1]])
   }
-}
-
-
-# handle missing data and absent nodes for multiple time points with lags
-preprocess <- function(object, ..., lag = FALSE, covariate = FALSE, 
-    memory = c("no", "autoregression", "stability", "innovation", "loss"), 
-    na = NA, na.method = "fillmode", structzero = -9, 
-    structzero.method = "remove", verbose = FALSE) {
-  
-  # save objects in a list
-  l <- as.list(match.call())[-1]  # names of all objects including 'object'
-  arg <- c("lag", "covariate", "memory", "na", "na.method", "structzero", 
-      "structzero.method", "verbose")  # these args are not included as objects
-  for (i in 1:length(arg)) {
-    if (arg[i] %in% names(l)) {
-      l <- l[-which(names(l) == arg[i])]
-    }
-  }
-  for (i in 1:length(l)) {  # save the objects in list, not just the names
-    l[[i]] <- eval(l[[i]], envir = .GlobalEnv)
-    if (class(l[[i]]) != "list") {
-      l[[i]] <- list(l[[i]])
-    }
-  }
-  
-  # check number of time steps; what is the length of the longest list in l?
-  t <- 1
-  for (i in 1:length(l)) {
-    if (class(l[[i]]) == "list" && length(l[[i]]) > t) {
-      t <- length(l[[i]])
-    }
-  }
-  
-  # make sure that all lists have the same length
-  for (i in 1:length(l)) {
-    if (length(l[[i]]) == 1 && t > 1) {
-      for (j in 2:t) {
-        l[[i]][[j]] <- l[[i]][[1]]
-      }
-    }
-    if (length(l[[i]]) != t) {
-      stop(paste("Object", i, "does not contain the right number of elements."))
-    }
-  }
-  
-  # infer labels if length corresponds to largest item otherwise in list
-  largest.nr <- 0
-  largest.row.labels <- character()
-  largest.nc <- 0
-  largest.col.labels <- character()
-  for (i in 1:length(l)) {  # find largest items and save their labels
-    for (j in 1:length(l[[i]])) {
-      if (class(l[[i]][[j]]) == "matrix" || class(l[[i]][[j]]) == "network") {
-        if (nrow(as.matrix(l[[i]][[j]])) > largest.nr && 
-            !is.null(rownames(as.matrix(l[[i]][[j]])))) {
-          largest.nr <- nrow(as.matrix(l[[i]][[j]]))
-          largest.row.labels <- rownames(as.matrix(l[[i]][[j]]))
-        }
-        if (ncol(as.matrix(l[[i]][[j]])) > largest.nc && 
-            !is.null(colnames(as.matrix(l[[i]][[j]])))) {
-          largest.nc <- ncol(as.matrix(l[[i]][[j]]))
-          largest.col.labels <- colnames(as.matrix(l[[i]][[j]]))
-        }
-      } else if (class(l[[i]][[j]]) == "data.frame") {
-        if (nrow((l[[i]][[j]]) > largest.nr && 
-            !is.null(rownames(l[[i]][[j]])))) {
-          largest.nr <- nrow(l[[i]][[j]])
-          largest.row.labels <- rownames(l[[i]][[j]])
-        }
-      } else if (is.vector(l[[i]][[j]]) && length(l[[i]][[j]]) > largest.nr && 
-          !is.null(names(l[[i]][[j]]))) {
-        largest.nr <- length(l[[i]][[j]])
-        largest.row.labels <- names(l[[i]][[j]])
-      }
-    }
-  }
-  if (largest.nc == 0) {  # if col labels are never given, assume same as row l.
-    largest.nc <- largest.nr
-    largest.col.labels <- largest.row.labels
-  }
-  
-  for (i in 1:length(l)) {
-    for (j in 1:length(l[[i]])) {
-      if (class(l[[i]][[j]]) == "matrix") {
-        if (nrow(l[[i]][[j]]) == largest.nr && is.null(rownames(l[[i]][[j]]))) {
-          rownames(l[[i]][[j]]) <- largest.row.labels
-        }
-        if (ncol(l[[i]][[j]]) == largest.nc && is.null(colnames(l[[i]][[j]]))) {
-          colnames(l[[i]][[j]]) <- largest.col.labels
-        }
-      } else if (class(l[[i]][[j]]) == "network") {
-        if (nrow(as.matrix(l[[i]][[j]])) == largest.nr && is.null(rownames(
-            as.matrix(l[[i]][[j]])))) {
-          if (!is.bipartite(l[[i]][[j]])) {
-            l[[i]][[j]] <- set.vertex.attribute(l[[i]][[j]], "vertex.names", 
-                largest.row.labels)
-          } else {
-            l[[i]][[j]] <- set.vertex.attribute(l[[i]][[j]], "vertex.names", 
-                c(largest.row.labels, get.vertex.attribute(l[[i]][[j]], 
-                "vertex.names")[(nrow(as.matrix(l[[i]][[j]]) + 1):ncol(
-                as.matrix(l[[i]][[j]])))]))
-          }
-        }
-        if (ncol(as.matrix(l[[i]][[j]])) == largest.nc && is.null(colnames(
-            as.matrix(l[[i]][[j]]))) && is.bipartite(l[[i]][[j]])) {
-          l[[i]][[j]] <- set.vertex.attribute(l[[i]][[j]], "vertex.names", 
-          c(get.vertex.attribute(l[[i]][[j]], 
-              "vertex.names")[1:nrow(as.matrix(l[[i]][[j]]))], 
-              largest.col.labels))
-        }
-      } else if (class(l[[i]][[j]]) == "data.frame" && is.null(
-          rownames(l[[i]][[j]])) && nrow(l[[i]][[j]]) == largest.nr) {
-        rownames(l[[i]][[j]]) <- largest.row.labels
-      } else if (is.vector(l[[i]][[j]]) && length(l[[i]][[j]]) == largest.nr && 
-          is.null(names(l[[i]][[j]]))) {
-        names(l[[i]][[j]]) <- largest.row.labels
-      }
-    }
-  }
-  
-  # remove or replace NA values
-  for (i in 1:length(l)) {
-    for (j in 1:length(l[[i]])) {
-      for (k in 1:length(na)) {
-        if (verbose == TRUE) {
-          l[[i]][[j]] <- handleMissings(l[[i]][[j]], na = na[k], 
-              method = na.method)
-        } else {
-          l[[i]][[j]] <- suppressMessages(handleMissings(l[[i]][[j]], 
-              na = na[k], method = na.method))
-        }
-      }
-      for (k in 1:length(structzero)) {
-        if (verbose == TRUE) {
-          l[[i]][[j]] <- handleMissings(l[[i]][[j]], na = structzero[k], 
-              method = structzero.method)
-        } else {
-          l[[i]][[j]] <- suppressMessages(handleMissings(l[[i]][[j]], 
-              na = structzero[k], method = structzero.method))
-        }
-      }
-    }
-  }
-  
-  # adjust matrix dimensions to each other cross-sectionally (across list items)
-  for (i in 1:t) {
-    for (j in 1:length(l)) {
-      for (k in 1:length(l)) {
-        tryCatch({
-          l[[j]][[i]] <- adjust(l[[j]][[i]], l[[k]][[i]], add = FALSE)
-        }, error = function(e) {
-          stop(paste0("The following error was encountered when executing ", 
-              "the adjust function at time step ", i, ": ", e))
-        })
-      }
-    }
-  }
-  
-  # forward adjustment for lagged covariates
-  forward <- l
-  if (lag == TRUE && t > 1) {
-    for (i in 1:length(forward)) {
-      for (j in 1:(t - 1)) {
-        forward[[i]][[j]] <- adjust(forward[[i]][[j]], forward[[i]][[j + 1]], 
-            remove = TRUE, add = FALSE)
-      }
-      if (covariate == TRUE) {  # remove last time step
-        forward[[i]] <- forward[[i]][-t]
-      }  # result if covariate = TRUE and lag = TRUE
-    }
-  }
-  # backward adjustment for dependent networks when lagged cov are present
-  if (lag == TRUE && t > 1) {
-    backward <- l
-    for (i in 1:length(backward)) {
-      for (j in 2:t) {
-        backward[[i]][[j]] <- adjust(backward[[i]][[j]], forward[[i]][[j - 1]], 
-            add = FALSE)
-      }
-      backward[[i]] <- backward[[i]][-1]  # remove first time step
-    }  # result when covariate = FALSE and lag = TRUE
-  }
-  
-  # create memory term
-  if (memory[1] == "no") {
-    # no memory term
-  } else if (memory[1] %in% c("stability", "autoregression", "innovation", 
-      "loss")) {
-    if (lag == FALSE || covariate == FALSE) {
-      stop(paste("Memory terms can only be created in conjunction with", 
-          "'lag = TRUE' and 'covariate = TRUE'."))
-    }
-    if (t < 2) {
-      stop("Only one time step. Memory term cannot be created.")
-    }
-    
-    # compute memory terms by comparing forward with backward matrices
-    memlist <- list()
-    for (i in 1:length(forward[[1]])) {
-      if (memory[1] == "autoregression") {
-        memlist[[i]] <- as.matrix(forward[[1]][[i]])
-      } else if (memory[1] == "stability") {
-        memlist[[i]] <- as.matrix(forward[[1]][[i]])
-        memlist[[i]][memlist[[i]] == 0] <- -1
-      } else if (memory[1] == "innovation") {
-        memlist[[i]] <- (as.matrix(forward[[1]][[i]]) * -1 + 1) * as.matrix(
-            backward[[1]][[i]])
-      } else if (memory[1] == "loss") {
-        memlist[[i]] <- as.matrix(forward[[1]][[i]]) * (1 - as.matrix(
-            backward[[1]][[i]]))
-      } else {
-        stop("'memory' argument not recognized.")
-      }
-    }
-    
-    # assign names
-    names(memlist) <- paste0("t", 1:length(forward[[1]]), "-t", 
-        2:(length(forward[[1]]) + 1))
-  } else {
-    stop("The 'memory' argument was not recognized.")
-  }
-  
-  # determine return object
-  if (covariate == FALSE && lag == TRUE) {
-    obj <- backward[[1]]
-  } else if (covariate == TRUE && lag == TRUE) {
-    if (memory[1] == "no") {
-      obj <- forward[[1]]
-    } else {
-      obj <- memlist
-    }
-  } else {
-    obj <- l[[1]]
-  }
-  if (class(obj) == "list" && length(obj) == 1) {
-    obj <- obj[[1]]
-  }
-  return(obj)
-}
-
+}
\ No newline at end of file
